"use strict";
exports.__esModule = true;
var types = require("@babel/types");
var path_1 = require("path");
/**
 * 检测是否是 NEJ.define 函数
 * @param {NodePath<CallExpression>} path
 * @return {boolean}
 */
function checkIsDefineFunction(path) {
    var node = path.node;
    return types.isIdentifier(node.callee) && node.callee.name === 'define'
        || (types.isMemberExpression(node.callee)
            && (types.isIdentifier(node.callee.object) && node.callee.object.name === 'NEJ')
            && (types.isIdentifier(node.callee.property) && node.callee.property.name === 'define'));
}
exports.checkIsDefineFunction = checkIsDefineFunction;
/**
 * 分离依赖中的类型和路径
 *
 * @param {string} source
 */
function splitModuleType(source) {
    var type = 'javascript';
    var rawSource = source;
    var textModuleReg = /^\b(json|text|regular)!/i;
    var result = textModuleReg.exec(source);
    if (result) {
        var _ = result[0];
        type = _.substring(0, _.length - 1).toLowerCase();
        rawSource = source.substring(_.length);
    }
    return [type, rawSource];
}
exports.splitModuleType = splitModuleType;
/**
 * 标准化路径, 去掉其中的 alias 和 "{}"
 *
 * @param {string} source
 * @param options
 */
function normalize(source, options) {
    var alias = options.alias, isNejCode = options.isNejCode;
    // 转换 nej 中的 {} 语法
    source = source.replace(/^{(.*?)}(.*?)/, '$1/$2');
    // 转换 alias
    source = source.replace(/^\b(.*?)\//, function (match, p1) {
        if (alias[p1]) {
            return alias[p1] + '/';
        }
        if (!isNejCode) {
            console.warn("alias " + p1 + " not match");
        }
        return p1 + "/";
    });
    // 未设置文件类型的添加 .js
    if (!path_1.extname(source)) {
        source += '.js';
    }
    return source;
}
exports.normalize = normalize;
/**
 * 分析依赖信息
 *
 * @param {string} rawSource
 * @param {string} name
 * @param options
 * @return {Dependence}
 */
function analyzeDependence(rawSource, name, options) {
    var _a = splitModuleType(rawSource), moduleType = _a[0], source = _a[1];
    source = normalize(source, options);
    return {
        source: source,
        name: name,
        rawSource: rawSource,
        moduleType: moduleType
    };
}
exports.analyzeDependence = analyzeDependence;
//# sourceMappingURL=parser.util.js.map